Logs — Glances 3.0.2 documentation

# Logs

A log messages list is displayed in the bottom of the screen if and only if:

- at least one `WARNING` or `CRITICAL` alert was occurred
- space is available in the bottom of the console/terminal

Each alert message displays the following information:

1. start datetime
2. duration if alert is terminated or ongoing if the alert is still in progress
3. alert name
4. {min,avg,max} values or number of running processes for monitored processes list alerts